@@ -19,11 +19,7 @@ import sys
 import os
 import argparse
 from pathlib import Path
-# from Bio import SeqIO
-# import subprocess
-# import multiprocessing as mp
 import shutil
-# from tqdm import tqdm
 import time
 import statistics
 import collections
@@ -41,6 +37,16 @@ def readFile(file):
     else:
         sys.exit('%s not found' % file)
 
+def removeEmptyLine(file):
+    if os.path.exists(file):
+        nf = open(file+'.temp','w')
+        with open(file,'r+') as f:
+            for line in f:
+                if not len(line.strip()) == 0:
+                    nf.write(line)
+        nf.close()
+        os.replace(file+'.temp', file)
+
 def addToDict(dict, groupID, seqID, type, value, cutoff):
     if not groupID in dict:
         dict[groupID] = '%s\t%s\t%s\t%s\t%s' % (groupID, type, seqID, value, cutoff)
@@ -236,34 +242,41 @@ def mode4(ppFile, missingGr, coreDir, coreSet, queryID):
                                 meanLen = float(l.split('\t')[1])
                             if l.split('\t')[0] == 'stdevLen':
                                 stdevLen = float(l.split('\t')[1])
+                        ppValue = abs(length - meanLen) / max(length, meanLen)
                         if stdevLen > 0:
-                            check = abs((length - meanLen) / stdevLen)
+                            check = abs((length - meanLen) / (2 * stdevLen))
                             if check <= 1:
-                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete', length, meanLen)
-                                geneCat['similar'].append(line+'\t0')
+                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete', length, '%s (sd=%s)' % (meanLen, stdevLen))
+                                # geneCat['similar'].append(line+'\t0')
+                                geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t1')
                             else:
-                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented', length, meanLen)
-                                geneCat['dissimilar'].append(line+'\t1')
+                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented', length, '%s (sd=%s)' % (meanLen, stdevLen))
+                                # geneCat['dissimilar'].append(line+'\t1')
+                                geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t0')
                         else:
-                            if abs(length - meanLen) > 0:
-                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete', length, meanLen)
-                                geneCat['similar'].append(line+'\t0')
+                            if (length - meanLen) > 0:
+                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete', length, '%s (sd=%s)' % (meanLen, stdevLen))
+                                # geneCat['similar'].append(line+'\t0')
+                                geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t1')
                             else:
-                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented', length, meanLen)
-                                geneCat['dissimilar'].append(line+'\t1')
+                                assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented', length, '%s (sd=%s)' % (meanLen, stdevLen))
+                                # geneCat['dissimilar'].append(line+'\t1')
+                                geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t0')
                     else:
                         noCutoff.append(groupID)
                 else:
                     if not groupID == 'geneID':
                         if groupID in missingGr:
-                            geneCat['missing'].append(line+'\t0')
+                            # geneCat['missing'].append(line+'\t0')
+                            geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t0.5')
                         else:
-                            geneCat['similar'].append(line+'\t0')
+                            # geneCat['similar'].append(line+'\t0')
+                            geneCat['similar'].append('\t'.join(line.split('\t')[0:-1])+'\t1')
     if flag == 1:
         # create new pp file
         newPP = '%s.mod' % ppFile
         newPPfile = open(newPP, 'w')
-        newPPfile.write('geneID\tncbiID\torthoID\tFAS\tAssessment\n')
+        newPPfile.write('geneID\tncbiID\torthoID\tAssessment\n')
         newPPfile.write('%s\n' % '\n'.join(geneCat['dissimilar']))
         newPPfile.write('%s\n' % '\n'.join(geneCat['similar']))
         newPPfile.write('%s\n' % '\n'.join(geneCat['missing']))
@@ -271,56 +284,56 @@ def mode4(ppFile, missingGr, coreDir, coreSet, queryID):
         shutil.move('%s.mod' % ppFile, ppFile)
     return(assessment, noCutoff, flag)
 
-def mode5(ppFile, coreDir, coreSet, queryID):
-    noCutoff = []
-    assessment = {}
-    for line in readFile(ppFile):
-        groupID = line.split('\t')[0]
-        # if queryID in line.split('\t')[2]:
-        if line.split('\t')[1] == 'ncbi'+str(queryID.split('@')[1]):
-            meanFas = float(line.split('\t')[3])
-            scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/3.cutoff' % (coreDir, coreSet, groupID)
-            if os.path.exists(scoreFile):
-                meanGroup = 0
-                for l in readFile(scoreFile):
-                    if l.split('\t')[0] == 'meanCons':
-                        meanGroup = float(l.split('\t')[1])
-                if meanFas >= meanGroup:
-                    assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
-                else:
-                    assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
-            else:
-                noCutoff.append(groupID)
-    return(assessment, noCutoff)
-
-def mode6(ppFile, coreDir, coreSet, queryID, outDir):
-    noCutoff = []
-    assessment = {}
-    # get refspec for each group
-    groupRefspec = {}
-    refspecFile = '%s/%s/%s/last_refspec.txt' % (outDir, coreSet, queryID)
-    for g in readFile(refspecFile):
-        groupRefspec[g.split('\t')[0]] = g.split('\t')[1]
-    # do assessment
-    for line in readFile(ppFile):
-        groupID = line.split('\t')[0]
-        # if queryID in line.split('\t')[2]:
-        if line.split('\t')[1] == 'ncbi'+str(queryID.split('@')[1]):
-            # meanFas = statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
-            meanFas = float(line.split('\t')[3])
-            scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/4.cutoff' % (coreDir, coreSet, groupID)
-            if os.path.exists(scoreFile):
-                meanRefspec = 0
-                for l in readFile(scoreFile):
-                    if l.split('\t')[0] == groupRefspec[groupID].strip():
-                        meanRefspec = float(l.split('\t')[1].strip())
-                if meanFas >= meanRefspec:
-                    assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
-                else:
-                    assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
-            else:
-                noCutoff.append(groupID)
-    return(assessment, noCutoff)
+# def mode5(ppFile, coreDir, coreSet, queryID):
+#     noCutoff = []
+#     assessment = {}
+#     for line in readFile(ppFile):
+#         groupID = line.split('\t')[0]
+#         # if queryID in line.split('\t')[2]:
+#         if line.split('\t')[1] == 'ncbi'+str(queryID.split('@')[1]):
+#             meanFas = float(line.split('\t')[3])
+#             scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/3.cutoff' % (coreDir, coreSet, groupID)
+#             if os.path.exists(scoreFile):
+#                 meanGroup = 0
+#                 for l in readFile(scoreFile):
+#                     if l.split('\t')[0] == 'meanCons':
+#                         meanGroup = float(l.split('\t')[1])
+#                 if meanFas >= meanGroup:
+#                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
+#                 else:
+#                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
+#             else:
+#                 noCutoff.append(groupID)
+#     return(assessment, noCutoff)
+#
+# def mode6(ppFile, coreDir, coreSet, queryID, outDir):
+#     noCutoff = []
+#     assessment = {}
+#     # get refspec for each group
+#     groupRefspec = {}
+#     refspecFile = '%s/%s/%s/last_refspec.txt' % (outDir, coreSet, queryID)
+#     for g in readFile(refspecFile):
+#         groupRefspec[g.split('\t')[0]] = g.split('\t')[1]
+#     # do assessment
+#     for line in readFile(ppFile):
+#         groupID = line.split('\t')[0]
+#         # if queryID in line.split('\t')[2]:
+#         if line.split('\t')[1] == 'ncbi'+str(queryID.split('@')[1]):
+#             # meanFas = statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
+#             meanFas = float(line.split('\t')[3])
+#             scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/4.cutoff' % (coreDir, coreSet, groupID)
+#             if os.path.exists(scoreFile):
+#                 meanRefspec = 0
+#                 for l in readFile(scoreFile):
+#                     if l.split('\t')[0] == groupRefspec[groupID].strip():
+#                         meanRefspec = float(l.split('\t')[1].strip())
+#                 if meanFas >= meanRefspec:
+#                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
+#                 else:
+#                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
+#             else:
+#                 noCutoff.append(groupID)
+#     return(assessment, noCutoff)
 
 def writeReport(assessment, outDir, coreDir, coreSet, queryID, mode):
     missing = '%s/%s/%s/missing.txt' % (outDir, coreSet, queryID)
@@ -375,14 +388,16 @@ def doAssessment(ppDir, coreDir, coreSet, queryID, outDir, mode):
     elif mode == 4:
         ppFile = '%s/%s_length.phyloprofile' % (ppDir, queryID)
         (assessment, noCutoff, flag) = mode4(ppFile, missingGr, coreDir, coreSet, queryID)
-    elif mode == 5:
-        ppFile = '%s/mode4.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode5(ppFile, coreDir, coreSet, queryID)
-    elif mode == 6:
-        ppFile = '%s/mode4.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode6(ppFile, coreDir, coreSet, queryID, outDir)
+    # elif mode == 5:
+    #     ppFile = '%s/mode4.phyloprofile' % (ppDir)
+    #     (assessment, noCutoff) = mode5(ppFile, coreDir, coreSet, queryID)
+    # elif mode == 6:
+    #     ppFile = '%s/mode4.phyloprofile' % (ppDir)
+    #     (assessment, noCutoff) = mode6(ppFile, coreDir, coreSet, queryID, outDir)
     # print full report
     stat = writeReport(assessment, outDir, coreDir, coreSet, queryID, mode)
+    # remove empty lines in pp file
+    removeEmptyLine(ppFile)
     return(noCutoff, stat, flag)
 
 def assessCompteness(args):
@@ -458,7 +473,7 @@ def assessCompteness(args):
     return(flag)
 
 def main():
-    version = '0.0.17'
+    version = '0.0.18'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
@@ -467,8 +482,8 @@ def main():
     required.add_argument('-o', '--outDir', help='Path to output directory', action='store', default='', required=True)
     required.add_argument('--queryID', help='ID of taxon of interest (e.g. HUMAN@9606@3)', action='store', default='', type=str, required=True)
     optional.add_argument('-m', '--mode',
-                        help='Score cutoff mode. (0) all modes, (1) mean of all-vs-all FAS scores, (2) mean FAS of refspec seed, (3) lower endpoint of CI of all-vs-all FAS scores, (4) mean and stdev of sequence length, (5) mean consensus, (6) reference consensus',
-                        action='store', default=0, choices=[0,1,2,3,4,5,6], type=int)
+                        help='Score cutoff mode. (0) all modes, (1) mean of all-vs-all FAS scores, (2) mean FAS of refspec seed, (3) lower endpoint of CI of all-vs-all FAS scores, (4) mean and stdev of sequence length',
+                        action='store', default=0, choices=[0,1,2,3,4], type=int)
     optional.add_argument('--force', help='Force overwrite existing data', action='store_true', default=False)
     args = parser.parse_args()
 
